import React, { useRef, useEffect } from 'react';
import { Box } from '@mui/material';
import { PROJECTED_TILE_SIZE } from 'src/config';
import { useResizeObserver } from 'src/hooks/useResizeObserver';

interface Props {
  url: string;
  onImageLoaded?: () => void;
}

export const IsometricIcon = ({ url, onImageLoaded }: Props) => {
  const ref = useRef() as React.MutableRefObject<HTMLImageElement>;
  const { size, observe, disconnect } = useResizeObserver();

  useEffect(() => {
    if (!ref.current) return;

    observe(ref.current);

    return disconnect;
  }, [observe, disconnect]);

  return (
    <img
      ref={ref}
      onLoad={onImageLoaded}
      src={url}
      style={{
        position: 'absolute',
        width: PROJECTED_TILE_SIZE.width,
        height: PROJECTED_TILE_SIZE.height,
        top: -size.height,
        left: -size.width / 2,
        pointerEvents: 'none'
      }}
    />
  );
};
