import React, { useMemo } from 'react';
import { Box, Typography, Stack } from '@mui/material';
import {
  PROJECTED_TILE_SIZE,
  DEFAULT_LABEL_HEIGHT,
  MARKDOWN_EMPTY_VALUE
} from 'src/config';
import { getTilePosition } from 'src/utils';
import { useIcon } from 'src/hooks/useIcon';
import { ViewItem } from 'src/types';
import { useModelItem } from 'src/hooks/useModelItem';
import { ExpandableLabel } from '@/components/Label/ExpandableLabel';
import { MarkdownEditor } from '@/components/MarkdownEditor/MarkdownEditor';
import { Card, CardContent } from '@/components/ui/card';

interface Props {
  node: ViewItem;
  order: number;
}

export const Node = ({ node, order }: Props) => {
  const modelItem = useModelItem(node.id);
  const { iconComponent } = useIcon(modelItem.icon);

  const position = useMemo(() => {
    return getTilePosition({
      tile: node.tile,
      origin: 'BOTTOM'
    });
  }, [node.tile]);

  const description = useMemo(() => {
    if (
      modelItem.description === undefined ||
      modelItem.description === MARKDOWN_EMPTY_VALUE
    )
      return null;

    return modelItem.description;
  }, [modelItem.description]);

  return (
    <div
      style={{
        position: 'absolute',
        height: PROJECTED_TILE_SIZE.height,
        width: PROJECTED_TILE_SIZE.width,
        zIndex: order
      }}
    >
      <div
        style={{
          position: 'absolute',
          left: position.x,
          top: position.y
        }}
      >
        {(modelItem.name || description) && (
          <Card
            style={{
              bottom: PROJECTED_TILE_SIZE.height / 2,
              position: 'absolute'
            }}
          >
            <CardContent>
              <ExpandableLabel
                maxWidth={250}
                expandDirection="BOTTOM"
                labelHeight={node.labelHeight ?? DEFAULT_LABEL_HEIGHT}
              >
                <Stack spacing={1}>
                  {modelItem.name && (
                    <Typography fontWeight={600}>{modelItem.name}</Typography>
                  )}
                  {modelItem.description &&
                    modelItem.description !== MARKDOWN_EMPTY_VALUE && (
                      <MarkdownEditor value={modelItem.description} readOnly />
                    )}
                </Stack>
              </ExpandableLabel>
            </CardContent>
          </Card>
        )}
        {iconComponent && (
          <div
            style={{
              height: PROJECTED_TILE_SIZE.height,
              width: PROJECTED_TILE_SIZE.width,
              // top: -PROJECTED_TILE_SIZE.height * 2,
              // left: -PROJECTED_TILE_SIZE.width / 2,
              position: 'absolute',
              pointerEvents: 'none'
            }}
          >
            {iconComponent}
          </div>
        )}
      </div>
    </div>
  );
};
